# =====================================
# generator=datazen
# version=3.2.3
# hash=18b776569e15d4363f48bde945c2b0f6
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "An interface generator for distributed computing."
PKG_NAME = "ifgen"
VERSION = "4.7.0"
